@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-certificates-extension.c,v 1.30 2006/07/24 19:36:03 chpe Exp $
+ *  $Id: ephy-certificates-extension.c,v 1.30.2.1 2006/09/06 20:12:06 chpe Exp $
  */
 
 #include "config.h"
@@ -80,7 +80,7 @@ ephy_certificates_extension_get_type (void)
 GType
 ephy_certificates_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyCertificatesExtensionClass),
 		NULL, /* base_init */
@@ -93,7 +93,7 @@ ephy_certificates_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_certificates_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_certificates_extension_iface_init,
 		NULL,
