@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-error-viewer-extension.c,v 1.27 2006/01/22 15:58:59 crispin Exp $
+ *  $Id: ephy-error-viewer-extension.c,v 1.28.4.1 2006/09/06 20:12:10 chpe Exp $
  */
 
 #include "config.h"
@@ -126,7 +126,7 @@ ephy_error_viewer_extension_get_type (void)
 GType
 ephy_error_viewer_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyErrorViewerExtensionClass),
 		NULL, /* base_init */
@@ -139,7 +139,7 @@ ephy_error_viewer_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_error_viewer_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_error_viewer_extension_iface_init,
 		NULL,
@@ -304,10 +304,10 @@ update_actions (EphyWindow *window)
 	content_type = mozilla_get_content_type (embed);
 
 	if (content_type &&
-            (strcmp (content_type, "text/html") == 0)
-	    || (strcmp (content_type, "application/xhtml+xml") == 0)
-	    || (strcmp (content_type, "application/xml") == 0)
-	    || (strcmp (content_type, "text/xml") == 0))
+            ((strcmp (content_type, "text/html") == 0)
+             || (strcmp (content_type, "application/xhtml+xml") == 0)
+             || (strcmp (content_type, "application/xml") == 0)
+             || (strcmp (content_type, "text/xml") == 0)))
 	{
 		g_value_set_boolean (&sensitive, TRUE);
 	}
