@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.11 2006/05/10 18:14:57 chpe Exp $
+ *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.12.2.1 2006/09/06 20:24:03 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -45,10 +45,10 @@
 NS_IMPL_ISUPPORTS1(ErrorViewerURICheckerObserver, nsIRequestObserver)
 
 ErrorViewerURICheckerObserver::ErrorViewerURICheckerObserver()
+  : mNumLinksChecked (0)
+  , mNumLinksInvalid (0)
+  , mNumLinksTotal (0)
 {
-	mNumLinksTotal = 0;
-	mNumLinksChecked = 0;
-	mNumLinksInvalid = 0;
 }
                                                                                 
 ErrorViewerURICheckerObserver::~ErrorViewerURICheckerObserver()
@@ -64,7 +64,7 @@ ErrorViewerURICheckerObserver::~ErrorViewerURICheckerObserver()
 						   mNumLinksInvalid),
 					 mNumLinksInvalid);
 
-		msg = g_strconcat (part1, "\n", part2, NULL);
+		msg = g_strconcat (part1, "\n", part2, (char *) NULL);
 
 		link_checker_append (mChecker, ERROR_VIEWER_INFO, msg);
 
