@@ -15,14 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerURICheckerObserver.h,v 1.3 2004/04/19 04:00:43 adamh Exp $
+ *  $Id: ErrorViewerURICheckerObserver.h,v 1.4 2006/05/10 18:14:57 chpe Exp $
  */
 
-#include "link-checker.h"
-
-#include <nsIDOMNode.h>
 #include <nsIRequestObserver.h>
 
+class nsIDOMNode;
+
+#include "link-checker.h"
+
 /* Header file */
 class ErrorViewerURICheckerObserver : public nsIRequestObserver
 {
