@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-css-menu.c,v 1.12 2005/04/19 11:30:19 chpe Exp $
+ *  $Id: ephy-css-menu.c,v 1.13.4.1 2006/09/06 20:12:27 chpe Exp $
  */
 
 #include "config.h"
@@ -89,7 +89,7 @@ ephy_css_menu_get_type (void)
 GType
 ephy_css_menu_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyCSSMenuClass),
 		NULL, /* base_init */
@@ -148,7 +148,7 @@ create_stylesheet_action (EphyCSSMenu *menu,
 			tooltip = g_strdup (_("Render the page using the default style"));
 			break;
 		default:
-			tooltip = g_strdup_printf (_("Render the page using the \"%s\" style"), 
+			tooltip = g_strdup_printf (_("Render the page using the “%s” style"), 
 						   name);
 			break;
 	}
