@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sidebar.c,v 1.4 2006/04/24 10:27:01 chpe Exp $
+ *  $Id: ephy-sidebar.c,v 1.4.2.1 2006/09/06 20:12:27 chpe Exp $
  */
 
 #include "config.h"
@@ -86,7 +86,7 @@ ephy_sidebar_get_type (void)
 GType
 ephy_sidebar_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphySidebarClass),
 		NULL, /* base_init */
